==> haskell-mono-traversable-1.0.21.0-127.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable
version:              1.0.21.0
visibility:           public
id:                   mono-traversable-1.0.21.0-9RUKUQu56O66rvR7vJ1jcU
key:                  mono-traversable-1.0.21.0-9RUKUQu56O66rvR7vJ1jcU
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, John Wiegley, Greg Weber
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Type classes for mapping, folding, and traversing monomorphic containers

description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>

category:             Data
abi:                  c9dffeef9fd73d61f3d3977fe4af5d76
exposed:              True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences

hidden-modules:       Paths_mono_traversable
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mono-traversable-1.0.21.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mono-traversable-1.0.21.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mono-traversable-1.0.21.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable
hs-libraries:         HSmono-traversable-1.0.21.0-9RUKUQu56O66rvR7vJ1jcU
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP
    vector-algorithms-0.9.1.0-nPezpE6T5gHv4BTs4clf9

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-1.0.21.0-128-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable
version:              1.0.21.0
visibility:           public
id:                   mono-traversable-1.0.21.0-DRPwtEa2I1e57PO0WNa046
key:                  mono-traversable-1.0.21.0-DRPwtEa2I1e57PO0WNa046
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, John Wiegley, Greg Weber
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Type classes for mapping, folding, and traversing monomorphic containers

description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>

category:             Data
abi:                  3a3d6903d343108a4832aaf264539144
exposed:              True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences

hidden-modules:       Paths_mono_traversable
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mono-traversable-1.0.21.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mono-traversable-1.0.21.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mono-traversable-1.0.21.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable
hs-libraries:         HSmono-traversable-1.0.21.0-DRPwtEa2I1e57PO0WNa046
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH
    vector-algorithms-0.9.1.0-GdPL2rq4cry7HNPKxZ4cz0

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
